<?php
// This file is part of the expcontent module for Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Define all the backup steps that will be used by the backup_expcontent_activity_task.
 *
 * @package    mod_expcontent
 * @copyright  2013 Mark Nelson <markn@moodle.com>, 2021 Klaus-Uwe Mitterer <kumitterer@kumi.systems>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die('Direct access to this script is forbidden.');

/**
 * Define the complete expcontent structure for backup, with file and id annotations.
 *
 * @package    mod_expcontent
 * @copyright  2013 Mark Nelson <markn@moodle.com>, 2021 Klaus-Uwe Mitterer <kumitterer@kumi.systems>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class backup_expcontent_activity_structure_step extends backup_activity_structure_step {

    /**
     * Define the structure of the backup file.
     *
     * @return backup_nested_element
     */
    protected function define_structure() {

        // The instance.
        $expcontent = new backup_nested_element('expcontent', array('id'), array(
            'name', 'contentid', 'intro', 'introformat', 'timecreated', 'timemodified'));

        // Define sources.
        $expcontent->set_source_table('expcontent', array('id' => backup::VAR_ACTIVITYID));

        // Return the root element (expcontent), wrapped into standard activity structure.
        return $this->prepare_activity_structure($expcontent);
    }
}
